==> qtjambi-xmlpatterns-5.15-sources.jar: io/qt/xmlpatterns/QXmlNamePool.java <==
package io.qt.xmlpatterns;


/**
 * <p>Table of shared strings referenced by instances of QXmlName</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlnamepool.html">QXmlNamePool</a></p>
 */
public class QXmlNamePool extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool">QXmlNamePool::QXmlNamePool()</a></p>
     */
    public QXmlNamePool(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlNamePool instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool-1">QXmlNamePool::QXmlNamePool(QXmlNamePool)</a></p>
     */
    public QXmlNamePool(io.qt.xmlpatterns.QXmlNamePool other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlNamePool instance, io.qt.xmlpatterns.QXmlNamePool other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlNamePool(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlNamePool clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlNamePool clone_native(long __this_nativeId);
}

==> qtjambi-xmlpatterns-5.15.10-sources.jar: io/qt/xmlpatterns/QXmlNamePool.java <==
package io.qt.xmlpatterns;


/**
 * <p>Table of shared strings referenced by instances of QXmlName</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlnamepool.html">QXmlNamePool</a></p>
 */
public class QXmlNamePool extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool">QXmlNamePool::QXmlNamePool()</a></p>
     */
    public QXmlNamePool(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlNamePool instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool-1">QXmlNamePool::QXmlNamePool(QXmlNamePool)</a></p>
     */
    public QXmlNamePool(io.qt.xmlpatterns.QXmlNamePool other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlNamePool instance, io.qt.xmlpatterns.QXmlNamePool other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlNamePool(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlNamePool clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlNamePool clone_native(long __this_nativeId);
}
